/**
 * @file
 * Javascript behaviors for Dropdown test.
 */

(function ($) {
  'use strict';
  Drupal.behaviors.ucDropdownTest = {
    attach: function (context) {
      // Test to avoid multiple scripts running.
      var results = $('main#content').find('div#results').html();
      if (typeof (results) == 'undefined') {
        $('main#content').prepend('<div id="results"><p>Test started</p></div>');
      }
      else {
        return;
      }

      // Open the attributes so they can be seen.
      $('form.uc-product-add-to-cart-form details').each(function () {
        $(this).find('summary').attr('aria-expanded', 'true');
        $(this).find('summary').attr('aria-pressed', 'true');
        $(this).attr('open', 'open');
      });

      $('div#results').append('<p>Product</p>');

      var pid = getProductID('Parent');
      var pcid = getProductID('Class parent');

      var parent = getAttributeID('Parent');
      var child = getAttributeID('Child');
      var grandchild = getAttributeID('Grandchild');
      if (child === 0) {
        $('div#results').append('<p style="color:green">Child attribute hidden</p>');
      }
      else {
        $('div#results').append('<p style="color:red">Error: Child attribute displayed</p>');
      }
      if (grandchild === 0) {
        $('div#results').append('<p style="color:green">Grandchild attribute hidden</p>');
      }
      else {
        $('div#results').append('<p style="color:red">Error: Grandchild attribute displayed</p>');
      }

      var oid = 0;
      $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + parent + '"]').find('input.form-checkbox').each(function () {
        if ($.isNumeric(this.value) &&
          (oid === 0 || oid > parseInt(this.value))) {

          oid = parseInt(this.value);
        }
      });
      if (oid > 0) {
        $('input[name="products[' + pid + '][attributes][' + parent + '][' + oid + ']"]').prop('checked', true);
        $('input[name="products[' + pid + '][attributes][' + parent + '][' + oid + ']"]').change();
        $('div#results').append('<p>Parent dependent option selected</p>');
      }

      setTimeout(function () {
        var child = getAttributeID('Child');
        if (child !== 0) {
          $('div#results').append('<p style="color:green">Child attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child attribute hidden</p>');
        }

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + child + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pid + '][attributes][' + child + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pid + '][attributes][' + child + '][' + oid + ']"]').change();
          $('div#results').append('<p>Child dependent option selected</p>');
        }
      }, 2000);

      setTimeout(function () {
        var grandchild = getAttributeID('Grandchild');
        if (grandchild !== 0) {
          $('div#results').append('<p style="color:green">Grandchild attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild attribute hidden</p>');
        }

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + grandchild + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pid + '][attributes][' + grandchild + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pid + '][attributes][' + grandchild + '][' + oid + ']"]').change();
          $('div#results').append('<p>Grandchild option selected</p>');
        }
      }, 4000);

      setTimeout(function () {
        var grandchild = getAttributeID('Grandchild');
        var count = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + grandchild + '"]').find('input.form-checkbox:checked').each(function () {
          count++;
        });
        if (count > 0) {
          $('div#results').append('<p style="color:green">Grandchild option displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild option hidden</p>');
        }
      }, 6000);

      setTimeout(function () {
        var parent = getAttributeID('Parent');

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + parent + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pid + '][attributes][' + parent + '][' + oid + ']"]').prop('checked', false);
          $('input[name="products[' + pid + '][attributes][' + parent + '][' + oid + ']"]').change();
          $('div#results').append('<p>Parent dependent option deselected</p>');
        }
      }, 8000);

      setTimeout(function () {
        var parent = getAttributeID('Parent');
        var child = getAttributeID('Child');
        var grandchild = getAttributeID('Grandchild');
        if (child === 0) {
          $('div#results').append('<p style="color:green">Child attribute hidden</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child attribute displayed</p>');
        }
        if (grandchild === 0) {
          $('div#results').append('<p style="color:green">Grandchild attribute hidden</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild attribute displayed</p>');
        }

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + parent + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pid + '][attributes][' + parent + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pid + '][attributes][' + parent + '][' + oid + ']"]').change();
          $('div#results').append('<p>Parent dependent option selected</p>');
        }
      }, 10000);

      setTimeout(function () {
        var child = getAttributeID('Child');
        if (child !== 0) {
          $('div#results').append('<p style="color:green">Child attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child attribute hidden</p>');
        }
        var count = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + child + '"]').find('input.form-checkbox:checked').each(function () {
          count++;
        });
        if (count === 0) {
          $('div#results').append('<p style="color:green">Child option removed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child option selected</p>');
        }

        oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + child + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pid + '][attributes][' + child + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pid + '][attributes][' + child + '][' + oid + ']"]').change();
          $('div#results').append('<p>Child dependent option selected</p>');
        }
      }, 12000);

      setTimeout(function () {
        var grandchild = getAttributeID('Grandchild');
        if (grandchild !== 0) {
          $('div#results').append('<p style="color:green">Grandchild attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild attribute hidden</p>');
        }
        var count = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pid + '-attributes-' + grandchild + '"]').find('input.form-checkbox:checked').each(function () {
          count++;
        });
        if (count === 0) {
          $('div#results').append('<p style="color:green">Grandchild option removed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild option selected</p>');
        }
      }, 14000);

      setTimeout(function () {
        $('div#results').append('<p>Product class</p>');

        var parent = getAttributeID('Class parent');
        var child = getAttributeID('Class child');
        var grandchild = getAttributeID('Class grandchild');
        if (child === 0) {
          $('div#results').append('<p style="color:green">Child attribute hidden</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child attribute displayed</p>');
        }
        if (grandchild === 0) {
          $('div#results').append('<p style="color:green">Grandchild attribute hidden</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild attribute displayed</p>');
        }

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + parent + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pcid + '][attributes][' + parent + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pcid + '][attributes][' + parent + '][' + oid + ']"]').change();
          $('div#results').append('<p>Parent dependent option selected</p>');
        }
      }, 16000);

      setTimeout(function () {
        var child = getAttributeID('Class child');
        if (child !== 0) {
          $('div#results').append('<p style="color:green">Child attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child attribute hidden</p>');
        }

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + child + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pcid + '][attributes][' + child + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pcid + '][attributes][' + child + '][' + oid + ']"]').change();
          $('div#results').append('<p>Child dependent option selected</p>');
        }
      }, 18000);

      setTimeout(function () {
        var grandchild = getAttributeID('Class grandchild');
        if (grandchild !== 0) {
          $('div#results').append('<p style="color:green">Grandchild attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild attribute hidden</p>');
        }

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + grandchild + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pcid + '][attributes][' + grandchild + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pcid + '][attributes][' + grandchild + '][' + oid + ']"]').change();
          $('div#results').append('<p>Grandchild option selected</p>');
        }
      }, 20000);

      setTimeout(function () {
        var grandchild = getAttributeID('Class grandchild');
        var count = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + grandchild + '"]').find('input.form-checkbox:checked').each(function () {
          count++;
        });
        if (count > 0) {
          $('div#results').append('<p style="color:green">Grandchild option displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild option hidden</p>');
        }
      }, 22000);

      setTimeout(function () {
        var parent = getAttributeID('Class parent');

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + parent + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pcid + '][attributes][' + parent + '][' + oid + ']"]').prop('checked', false);
          $('input[name="products[' + pcid + '][attributes][' + parent + '][' + oid + ']"]').change();
          $('div#results').append('<p>Parent dependent option deselected</p>');
        }
      }, 24000);

      setTimeout(function () {
        var parent = getAttributeID('Class parent');
        var child = getAttributeID('Class child');
        var grandchild = getAttributeID('Class grandchild');
        if (child === 0) {
          $('div#results').append('<p style="color:green">Child attribute hidden</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child attribute displayed</p>');
        }
        if (grandchild === 0) {
          $('div#results').append('<p style="color:green">Grandchild attribute hidden</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild attribute displayed</p>');
        }

        var oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + parent + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pcid + '][attributes][' + parent + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pcid + '][attributes][' + parent + '][' + oid + ']"]').change();
          $('div#results').append('<p>Parent dependent option selected</p>');
        }
      }, 26000);

      setTimeout(function () {
        var child = getAttributeID('Class child');
        if (child !== 0) {
          $('div#results').append('<p style="color:green">Child attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child attribute hidden</p>');
        }
        var count = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + child + '"]').find('input.form-checkbox:checked').each(function () {
          count++;
        });
        if (count === 0) {
          $('div#results').append('<p style="color:green">Child option removed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Child option selected</p>');
        }

        oid = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + child + '"]').find('input.form-checkbox').each(function () {
          if ($.isNumeric(this.value) &&
            (oid === 0 || oid > parseInt(this.value))) {

            oid = parseInt(this.value);
          }
        });
        if (oid > 0) {
          $('input[name="products[' + pcid + '][attributes][' + child + '][' + oid + ']"]').prop('checked', true);
          $('input[name="products[' + pcid + '][attributes][' + child + '][' + oid + ']"]').change();
          $('div#results').append('<p>Child dependent option selected</p>');
        }
      }, 28000);

      setTimeout(function () {
        var grandchild = getAttributeID('Class grandchild');
        if (grandchild !== 0) {
          $('div#results').append('<p style="color:green">Grandchild attribute displayed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild attribute hidden</p>');
        }
        var count = 0;
        $('fieldset[data-drupal-selector="edit-products-' + pcid + '-attributes-' + grandchild + '"]').find('input.form-checkbox:checked').each(function () {
          count++;
        });
        if (count === 0) {
          $('div#results').append('<p style="color:green">Grandchild option removed</p>');
        }
        else {
          $('div#results').append('<p style="color:red">Error: Grandchild option selected</p>');
        }

        $('div#results').append('<p>Test finished.</p>');
      }, 30000);
    }
  };

  var getProductID = function (label) {
    var pid = 0;
    $('form.uc-product-add-to-cart-form details').each(function () {
      $('legend span.fieldset-legend').each(function () {
        if (label === $(this).html()) {
          var attr = $(this).parent().parent().attr('id');
          var attribute = attr.split('-');
          pid = attribute[2];
        }
      });
    });
    return pid;
  };

  var getAttributeID = function (label) {
    var aid = 0;
    $('legend span.fieldset-legend').each(function () {
      if (label === $(this).html()) {
        var attr = $(this).parent().parent().find('div.fieldset-wrapper').find('div.form-checkboxes').attr('id');
        var attribute = attr.split('-');
        aid = attribute[4];
      }
    });
    return aid;
  };

})(jQuery);
